package control;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;
import java.util.ArrayList;
import java.util.Collection;
import java.util.HashMap;

/**
 * 
 * @author Angela Lucchi
 * Classe astratta che gestisce magazzino e negozio
 * @param <T>
 */
public abstract class Gestore<T> implements IGestore<T> {
    protected HashMap<Integer, T> prodotti;

    protected Gestore() {
        this.prodotti = new HashMap<Integer, T>(30);
    }

    /**
     * Metodo che ritorna un prodotto
     * 
     * @param codice
     * @return il prodotto col codice cercato
     */
    public T get(int key) {
        return this.prodotti.get(key);
    }

    /**
     * Metodo che restituisce una collezione contenente gli oggetti presenti
     * nella mappa
     * 
     * @return lista dei prodotti
     */
    public Collection<T> getList() {
        return (Collection<T>) this.prodotti.values();
    }

    /**
     * Metodo che assegna automaticamente un codice
     * 
     * @return codice
     */
    public int assegnaCodice() {
        int i = this.prodotti.values().size();
        while (this.prodotti.get(i) != null) {
            i++;
        }
        return i;
    }

    @Override
    public String toString() {
        String s = "";
        for (T object : this.getList()) {
            s += object.toString() + "\n";
        }
        return s;
    }

    /**
     * Metodo che salva su file
     */
    public void salva() {
        try {
            FileOutputStream fileOut = new FileOutputStream(daiPercorso());
            ObjectOutputStream out = new ObjectOutputStream(fileOut);
            out.writeObject(this.prodotti);
            out.close();
            fileOut.close();
        } catch (Exception i) {
            i.printStackTrace();
        }
    }

    /**
     * Metodo che carica le informazioni dal file
     */
    @SuppressWarnings("unchecked")
    public void carica() {
        try {
            File f = new File(daiPercorso());
            if (!f.exists()) {
                return;
            }

            FileInputStream fileIn = new FileInputStream(f);
            ObjectInputStream in = new ObjectInputStream(fileIn);
            Object o = in.readObject();
            this.prodotti = (HashMap<Integer, T>) o;
            in.close();
            fileIn.close();
        } catch (IOException i) {
            i.printStackTrace();
            return;
        } catch (ClassNotFoundException c) {
            System.out.println("Classe non trovata!");
            c.printStackTrace();
            return;
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    /**
     * Metodo astratto che ritorna il percorso del file in cui vengono salvati e
     * da cui vengono caricati i dati
     * 
     * @return il percorso
     */
    public abstract String daiPercorso();

    public abstract ArrayList<T> cerca(String s);

}
