package control;

import java.util.ArrayList;

import exception.ExceptionEqualName;
import exception.ExceptionNegativeNumber;
import exception.ExceptionNegativeQty;
import model.ProdottoMagazzino;

/**
 * 
 * @author Angela Lucchi
 * Classe che gestisce il magazzino
 */
public class GestoreMagazzino extends Gestore<ProdottoMagazzino> {
    private static GestoreMagazzino magazzino = null;
    public final static String PERCORSO = "prodottimag.prod";

    /**
     * Metodo che ritorna un'unica istanza
     * 
     * @return l'istanza
     */
    public static GestoreMagazzino daiIstanza() {
        if (GestoreMagazzino.magazzino == null) {
            GestoreMagazzino.magazzino = new GestoreMagazzino();
            GestoreMagazzino.magazzino.carica();
        }
        return GestoreMagazzino.magazzino;
    }

    /**
     * @return il percorso
     */
    @Override
    public String daiPercorso() {
        return PERCORSO;
    }

    /**
     * Cerca un prodotto per nome
     * 
     * @param stringa
     *            da cercare
     * @return lista dei prodotti il cui nome contiene la stringa
     */
    public ArrayList<ProdottoMagazzino> cerca(String s) {
        ArrayList<ProdottoMagazzino> lista = new ArrayList<>(20);
        for (ProdottoMagazzino prod : getList()) {
            if (prod.getNome().contains(s)) {
                lista.add(prod);
            }
        }
        return lista;
    }

    /**
     * Aggiunge un prodotto al magazzino
     * 
     * @param prod
     * @throws ExceptionEqualName
     */
    public void aggiungiProdM(ProdottoMagazzino prod) throws ExceptionEqualName {
        for (ProdottoMagazzino p : this.getList()) {
            if (p.getNome().equals(prod.getNome())) {
                throw new ExceptionEqualName();
            }
        }
        prod.setCodice(this.assegnaCodice());
        this.prodotti.put(prod.getCodice(), prod);
        this.salva();
    }

    /**
     * Rimuove un prodotto dal magazzino
     * 
     * @param codice
     */
    public void rimuoviProdM(int codice) {
        this.prodotti.remove(codice);
        salva();
    }

    /**
     * Metodo che ordina una quantit dal fornitore
     * 
     * @param codice
     * @param quantita
     * @throws ExceptionNegativeNumber
     */
    public void ordinaProd(int codice, int quantita) throws ExceptionNegativeNumber {

        if (quantita <= 0) {
            throw new ExceptionNegativeNumber();
        }
        ProdottoMagazzino prod;
        int dispo;
        prod = this.get(codice);
        dispo = prod.getDisponibilita();
        prod.setDisponibilita(quantita + dispo);
        this.prodotti.remove(codice);
        this.prodotti.put(codice, prod);
        salva();
    }

    /**
     * Metodo che manda una quantit del prodotto selezionato al negozio
     * 
     * @param codice
     * @param quantita
     * @throws ExceptionNegativeNumber
     * @throws ExceptionNegativeQty
     */
    public void mandaProd(int codice, int quantita) throws ExceptionNegativeNumber, ExceptionNegativeQty {
        int qty = 0;
        if (quantita <= 0) {
            throw new ExceptionNegativeNumber();
        }
        ProdottoMagazzino prod;
        int dispo;
        prod = this.get(codice);
        dispo = prod.getDisponibilita();
        qty = dispo - quantita;
        if (qty < 0) {
            throw new ExceptionNegativeQty();
        }
        if (qty == 0) {
            this.prodotti.remove(codice);
        } else {
            prod.setDisponibilita(qty);
            this.prodotti.remove(codice);
            this.prodotti.put(codice, prod);
        }
        salva();
    }
}
