package control;

import java.util.ArrayList;
import exception.ExceptionNegativeNumber;
import exception.ExceptionNegativeQty;
import model.ProdottoNegozio;

/**
 * 
 * @author Angela Lucchi 
 * Classe che gestisce il negozio
 */
public class GestoreNegozio extends Gestore<ProdottoNegozio> {
    private static GestoreNegozio negozio = null;
    public final static String PERCORSO = "prodottineg.prod";

    /**
     * @return un'unica istanza
     */
    public static GestoreNegozio daiIstanza() {
        if (GestoreNegozio.negozio == null) {
            GestoreNegozio.negozio = new GestoreNegozio();
            GestoreNegozio.negozio.carica();
        }
        return GestoreNegozio.negozio;

    }

    /**
     * @return il percoso attuale
     */
    @Override
    public String daiPercorso() {
        return PERCORSO;
    }

    /**
     * Cerca un prodotto per nome
     * 
     * @param stringa
     *            da cercare
     * @return lista dei prodotti il cui nome contiene la stringa
     */
    public ArrayList<ProdottoNegozio> cerca(String s) {
        ArrayList<ProdottoNegozio> lista = new ArrayList<>(20);
        for (ProdottoNegozio prod : getList()) {
            if (prod.getNome().contains(s)) {
                lista.add(prod);
            }
        }
        return lista;
    }

    /**
     * Aggiunge un prodotto al negozio
     * 
     * @param prod
     */
    public void aggiungiProdN(ProdottoNegozio prod) {
        prod.setCodice(this.assegnaCodice());
        this.prodotti.put(prod.getCodice(), prod);
        salva();
    }

    /**
     * Rimuove un prodotto dal negozio
     * 
     * @param codice
     */
    public void rimuoviProdN(int codice) {
        this.prodotti.remove(codice);
        salva();
    }

    /**
     * @param nome
     * @return il codice del prodotto a partire dal nome
     */
    public int getChiave(String nome) {
        for (ProdottoNegozio p : this.getList()) {
            if (p.getNome().equals(nome)) {
                return p.getCodice();
            }
        }
        return -1;
    }

    /**
     * Vendi una certa quantit del prodotto selezionato
     * 
     * @param codice
     * @param quantita
     * @throws ExceptionNegativeNumber
     * @throws ExceptionNegativeQty
     */
    public void vendiProd(int codice, int quantita) throws ExceptionNegativeNumber, ExceptionNegativeQty {

        int qty = 0;
        if (quantita <= 0) {
            throw new ExceptionNegativeNumber();
        }
        ProdottoNegozio prod;
        int dispo;
        prod = this.get(codice);
        dispo = prod.getDisponibilita();
        qty = dispo - quantita;
        if (qty < 0) {
            throw new ExceptionNegativeQty();
        }
        prod.setDisponibilita(qty);
        if (qty == 0) {
            this.prodotti.remove(codice);
        } else {
            this.prodotti.remove(codice);
            this.prodotti.put(codice, prod);
        }
        salva();
    }

    /**
     * Metodo per modificare un prodotto
     * 
     * @param chiave
     * @param pro
     */
    public void modificaProd(int chiave, ProdottoNegozio pro) {
        int qty = pro.getDisponibilita();
        int dispo = this.prodotti.get(chiave).getDisponibilita();
        pro.setDisponibilita(qty + dispo);
        this.prodotti.remove(chiave);
        this.prodotti.put(chiave, pro);
    }

    /**
     * @param name
     * @return se esiste un prodotto con il nome cercato
     */
    public boolean contieneNome(String nome) {
        for (ProdottoNegozio p : this.getList()) {
            if (p.getNome().equals(nome)) {
                return true;
            }
        }
        return false;
    }
}
