package view.magazzino;

import java.awt.event.MouseAdapter;
import java.awt.event.MouseEvent;
import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;
import java.util.Collection;

import javax.swing.JButton;
import javax.swing.JFrame;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JTable;
import javax.swing.JTextField;
import javax.swing.ListSelectionModel;
import javax.swing.border.EmptyBorder;
import javax.swing.table.DefaultTableModel;

import view.MainFrame;
import control.GestoreMagazzino;
import model.ProdottoMagazzino;

/**
 * @author Angela Lucchi 
 * Frame che permette di effettuare tutte le operazioni in
 *         magazzino
 */
public class GestioneMagazzino extends JFrame {
    private static final long serialVersionUID = 1L;

    private JPanel contentPane;
    private JTextField cerca;
    private JTable tabella;

    /**
     * Metodo che ridisegna la tabella dei prodotti
     * 
     * @param lista
     */
    public void refreshTable(Collection<ProdottoMagazzino> lista) {
        DefaultTableModel dtm = new DefaultTableModel() {
            private static final long serialVersionUID = 1L;

            public boolean isCellEditable(int row, int column) {
                return false;
            }
        };
        String intestazione[] = new String[] { "Codice Prodotto", "Nome prodotto", "Tipo prodotto", "Prezzo",
                "Quantit" };
        dtm.setColumnIdentifiers(intestazione);
        tabella.getTableHeader().setReorderingAllowed(false);
        tabella.setModel(dtm);
        for (ProdottoMagazzino prod : lista) {
            dtm.addRow(new Object[] { prod.getCodice(), prod.getNome(), prod.getTipo(), prod.getPrezzo(),
                    prod.getDisponibilita() });
        }
    }

    /**
     * Creazione del frame.
     */
    public GestioneMagazzino() {
        this.setResizable(false);
        this.setTitle("GESTIONE MAGAZZINO");
        this.addWindowListener(new WindowAdapter() {
            @Override
            public void windowOpened(WindowEvent e) {
                refreshTable(GestoreMagazzino.daiIstanza().getList());
            }
        });
        this.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
        this.setBounds(100, 100, 814, 372);
        contentPane = new JPanel();
        contentPane.setBorder(new EmptyBorder(5, 5, 5, 5));
        this.setContentPane(contentPane);
        contentPane.setLayout(null);

        JScrollPane scrollPane = new JScrollPane();
        scrollPane.setBounds(170, 42, 632, 270);
        contentPane.add(scrollPane);

        tabella = new JTable();
        scrollPane.setViewportView(tabella);
        tabella.setSelectionMode(ListSelectionModel.SINGLE_SELECTION);

        cerca = new JTextField();
        cerca.setBounds(170, 11, 632, 20);
        contentPane.add(cerca);
        cerca.setColumns(10);

        JButton btnCerca = new JButton("CERCA");
        btnCerca.addMouseListener(new MouseAdapter() {
            @Override
            public void mouseClicked(MouseEvent e) {
                refreshTable(GestoreMagazzino.daiIstanza().cerca(cerca.getText()));
            }
        });
        btnCerca.setBounds(10, 10, 142, 23);
        contentPane.add(btnCerca);

        JButton btnAggiungi = new JButton("AGGIUNGI");
        btnAggiungi.addMouseListener(new MouseAdapter() {
            @Override
            public void mouseClicked(MouseEvent e) {
                chiudi();
                new AggiungiProdottoMag().setVisible(true);
            }
        });
        btnAggiungi.setBounds(10, 45, 142, 23);
        contentPane.add(btnAggiungi);

        JButton btnRimuovi = new JButton("RIMUOVI");
        btnRimuovi.addMouseListener(new MouseAdapter() {
            @Override
            public void mouseClicked(MouseEvent e) {
                DefaultTableModel model = (DefaultTableModel) tabella.getModel();
                if (tabella.getSelectedRow() >= 0) {
                    int codice = (int) model.getValueAt(tabella.getSelectedRow(), 0);
                    GestoreMagazzino.daiIstanza().rimuoviProdM(codice);
                    cerca.setText("");
                    refreshTable(GestoreMagazzino.daiIstanza().getList());
                }
            }
        });
        btnRimuovi.setBounds(10, 79, 142, 23);
        contentPane.add(btnRimuovi);

        JButton btnOrdina = new JButton("ORDINA");
        btnOrdina.addMouseListener(new MouseAdapter() {
            @Override
            public void mouseClicked(MouseEvent e) {
                DefaultTableModel model = (DefaultTableModel) tabella.getModel();
                if (tabella.getSelectedRow() >= 0) {
                    int codice = (int) model.getValueAt(tabella.getSelectedRow(), 0);
                    new OrdinaFrame(codice).setVisible(true);
                    chiudi();
                }
            }
        });
        btnOrdina.setBounds(10, 113, 142, 23);
        contentPane.add(btnOrdina);

        JButton btnManda = new JButton("MANDA A NEGOZIO");
        btnManda.addMouseListener(new MouseAdapter() {
            @Override
            public void mouseClicked(MouseEvent e) {
                DefaultTableModel model = (DefaultTableModel) tabella.getModel();
                if (tabella.getSelectedRow() >= 0) {
                    int codice = (int) model.getValueAt(tabella.getSelectedRow(), 0);
                    new MandaFrame(codice).setVisible(true);
                    chiudi();
                }
            }
        });
        btnManda.setBounds(10, 147, 142, 23);
        contentPane.add(btnManda);

        JButton btnIndietro = new JButton("INDIETRO");
        btnIndietro.addMouseListener(new MouseAdapter() {
            public void mouseClicked(MouseEvent e) {
                new MainFrame().setVisible(true);
                chiudi();
            }
        });
        btnIndietro.setBounds(10, 181, 142, 23);
        contentPane.add(btnIndietro);
    }

    /**
     * Chiusura del frame
     */
    public void chiudi() {
        setVisible(false);
        dispose();
    }

}
