package view.negozio;

import java.awt.event.MouseAdapter;
import java.awt.event.MouseEvent;
import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;
import java.util.Collection;

import javax.swing.JButton;
import javax.swing.JFrame;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JTable;
import javax.swing.JTextField;
import javax.swing.ListSelectionModel;
import javax.swing.border.EmptyBorder;
import javax.swing.table.DefaultTableModel;

import control.GestoreNegozio;
import model.ProdottoNegozio;
import view.MainFrame;
import view.magazzino.GestioneMagazzino;

/**
 * 
 * @author Angela Lucchi
 * Classe che permette di effettuare tutte le operazioni in
 *         negozio
 */
public class GestioneNegozio extends JFrame {

	private static final long serialVersionUID = 1L;

	private JPanel contentPane;
	private JTextField cerca;
	private JTable tabella;

	/**
	 * Metodo che ridisegna la tabella dei prodotti
	 * 
	 * @param lista
	 */
	public void refreshTable(Collection<ProdottoNegozio> lista) {
		DefaultTableModel dtm = new DefaultTableModel() {
			private static final long serialVersionUID = 1L;

			public boolean isCellEditable(int row, int column) {
				return false;
			}
		};
		String intestazione[] = new String[] { "Codice Prodotto",
				"Nome prodotto", "Tipo prodotto", "Prezzo", "Quantit" };
		dtm.setColumnIdentifiers(intestazione);
		tabella.getTableHeader().setReorderingAllowed(false);
		tabella.setModel(dtm);
		for (ProdottoNegozio prod : lista) {
			dtm.addRow(new Object[] { prod.getCodice(), prod.getNome(),
					prod.getTipo(), prod.getPrezzo(), prod.getDisponibilita() });
		}
	}

	/**
	 * Creazione del frame.
	 */
	public GestioneNegozio() {
		this.setResizable(false);
		this.setTitle("GESTIONE NEGOZIO");
		this.addWindowListener(new WindowAdapter() {
			@Override
			public void windowOpened(WindowEvent e) {
				refreshTable(GestoreNegozio.daiIstanza().getList());
			}
		});
		this.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
		this.setBounds(170, 100, 850, 372);
		contentPane = new JPanel();
		contentPane.setBorder(new EmptyBorder(5, 5, 5, 5));
		this.setContentPane(contentPane);
		contentPane.setLayout(null);

		JScrollPane scrollPane = new JScrollPane();
		scrollPane.setBounds(200, 42, 632, 270);
		contentPane.add(scrollPane);

		tabella = new JTable();
		scrollPane.setViewportView(tabella);
		tabella.setSelectionMode(ListSelectionModel.SINGLE_SELECTION);

		cerca = new JTextField();
		cerca.setBounds(200, 11, 632, 20);
		contentPane.add(cerca);
		cerca.setColumns(10);

		JButton btnCerca = new JButton("CERCA");
		btnCerca.addMouseListener(new MouseAdapter() {
			@Override
			public void mouseClicked(MouseEvent e) {
				refreshTable(GestoreNegozio.daiIstanza()
						.cerca(cerca.getText()));
			}
		});
		btnCerca.setBounds(10, 10, 185, 23);
		contentPane.add(btnCerca);

		JButton btnRichiesta = new JButton("RICHIEDI");
		btnRichiesta.addMouseListener(new MouseAdapter() {
			@Override
			public void mouseClicked(MouseEvent e) {
				new GestioneMagazzino().setVisible(true);
				chiudi();
			}
		});
		btnRichiesta.setBounds(10, 45, 185, 23);
		contentPane.add(btnRichiesta);

		JButton btnVendi = new JButton("VENDI");
		btnVendi.addMouseListener(new MouseAdapter() {
			@Override
			public void mouseClicked(MouseEvent e) {
				DefaultTableModel model = (DefaultTableModel) tabella
						.getModel();
				if (tabella.getSelectedRow() >= 0) {
					int codice = (int) model.getValueAt(
							tabella.getSelectedRow(), 0);
					cerca.setText("");
					new VendiFrame(codice).setVisible(true);
					refreshTable(GestoreNegozio.daiIstanza().getList());
					chiudi();
				}
			}
		});
		btnVendi.setBounds(10, 79, 185, 23);
		contentPane.add(btnVendi);

		JButton btnIndietro = new JButton("INDIETRO");
		btnIndietro.addMouseListener(new MouseAdapter() {
			public void mouseClicked(MouseEvent e) {
				new MainFrame().setVisible(true);
				chiudi();
			}
		});
		btnIndietro.setBounds(10, 113, 185, 23);
		contentPane.add(btnIndietro);
	}

	/**
	 * Chiusura del frame
	 */
	public void chiudi() {
		setVisible(false);
		dispose();
	}
}
